"""
M/M/1 Queue Schema Definitions

Provides structured schema definitions for M/M/1 queuing systems
that can be consumed by LLMs through MCP.
"""

from .mm1_schema import MM1_SCHEMA

__all__ = ["MM1_SCHEMA"]
